@@ -1,27 +1,29 @@
 #' Search Europe PMC publication database
 #'
-#' @description This is the main function to search
-#' Europe PMC RESTful Web Service (\url{http://europepmc.org/RestfulWebService})
+#' @description This is the main function to search Europe PMC RESTful Web
+#'   Service (\url{http://europepmc.org/RestfulWebService}). It fully supports
+#'   the comprehensive Europe PMC query language. Simply copy & paste your query
+#'   terms to R. To get familiar with the Europe PMC query syntax, check the
+#'   Advanced Search Query Builder \url{https://europepmc.org/advancesearch}.
 #'
 #' @seealso \url{http://europepmc.org/Help}
 #'
-#' @param query character, search query. For more information on how to
-#'   build a search query, see \url{http://europepmc.org/Help}
-#' @param output character, what kind of output should be returned. One of 'parsed', 'id_list'
-#'   or 'raw' As default, parsed key metadata will be returned as data.frame.
-#'   'id_list' returns a list of IDs and sources.
-#'   Use 'raw' to get full metadata as list. Please be aware that these lists
-#'   can become very large.
-#' @param limit integer, limit the number of records you wish to retrieve.
-#'   By default, 100 are returned.
+#' @param query character, search query. For more information on how to build a
+#'   search query, see \url{http://europepmc.org/Help}
+#' @param output character, what kind of output should be returned. One of
+#'   'parsed', 'id_list' or 'raw' As default, parsed key metadata will be
+#'   returned as data.frame. 'id_list' returns a list of IDs and sources. Use
+#'   'raw' to get full metadata as list. Please be aware that these lists can
+#'   become very large.
+#' @param limit integer, limit the number of records you wish to retrieve. By
+#'   default, 100 are returned.
 #' @param synonym logical, synonym search. If TRUE, synonym terms from MeSH
-#'  terminology and the UniProt synonym list are queried, too. Disabled by
-#'  default.
-#' @param sort character, sort results by order (\code{asc}, \code{desc}) and
-#'  sort field (e.g. \code{CITED}, \code{P_PDATE}), seperated with a blank.
-#'  For example, sort results  by times cited in descending order:
-#'  \code{sort = 'CITED desc'}.
-#' @param verbose	logical, print some information on what is going on.
+#'   terminology and the UniProt synonym list are queried, too. Disabled by
+#'   default.
+#' @param sort character, relevance ranking is used by default. Use
+#'   \code{sort = 'cited'} for sorting by the number of citations, or
+#'   \code{sort = 'date'} by the most recent publications.
+#' @param verbose	logical, print progress bar. Activated by default.
 #' @return tibble
 #' @examples \dontrun{
 #' #Search articles for 'Gabi-Kat'
@@ -38,8 +40,8 @@
 #' #Limit search to 250 PLOS Genetics articles
 #' my.data <- epmc_search(query = 'ISSN:1553-7404', limit = 250)
 #'
-#' # include mesh and uniprot synonyms in search
-#' my.data <- epmc_search(query = 'aspirin', synonym = TRUE)
+#' # exclude MeSH synonyms in search
+#' my.data <- epmc_search(query = 'aspirin', synonym = FALSE)
 #'
 #' # get 100 most cited atricles from PLOS ONE
 #' epmc_search(query = 'ISSN:	1932-6203', sort = 'CITED desc')
@@ -53,30 +55,45 @@
 #' @export
 epmc_search <- function(query = NULL,
                         output = 'parsed',
-                        synonym = FALSE,
+                        synonym = TRUE,
                         verbose = TRUE,
                         limit = 100,
                         sort = NULL) {
+  #--- Input validation
   stopifnot(is.logical(c(verbose, synonym)))
+  stopifnot(is.numeric(limit))
+
+
+  # sort
+  if (!is.null(sort)) {
+    match.arg(sort, c("date", "cited"))
+    query <- switch(
+      sort,
+      date = paste(query, "sort_date:y"),
+      cited = paste(query, "sort_cited:y")
+    )
+  } else {
+    query <- query
+  }
   # get the correct hit count when mesh and uniprot synonyms are also searched
-  synonym <- ifelse(synonym == FALSE, "false", "true")
+  # synonym <- ifelse(synonym == FALSE, "false", "true")
   # this is so far the only way how I got the synonym paramworking after
   # the API change.
   # there is a possible conflict with the resumption token and decoding
   # the API call.
   query <- transform_query(paste0(query, "&synonym=", synonym))
-  stopifnot(is.numeric(limit))
+
   page_token <- "*"
   if (!output == "raw")
     results <- dplyr::data_frame()
   else
     results <- NULL
+  # search
   out <-
     epmc_search_(
       query = query,
       limit = limit,
       output = output,
-#      synonym = synonym,
       verbose = verbose,
       page_token = page_token,
       sort = sort
@@ -84,44 +101,48 @@ epmc_search <- function(query = NULL,
   res_chunks <- chunks(limit = limit)
   # super hacky to control limit, better approach using pageSize param needed
   hits <- epmc_hits(query, synonym = synonym)
-  if (hits == 0)
-    stop("There are no results matching your query")
-  limit <- as.integer(limit)
-  limit <- ifelse(hits <= limit, hits, limit)
-  # let's loop over until page max is reached,
-  # or until cursor marks are identical
-  i <- 0
-  while (i < res_chunks$page_max) {
-    out <-
-      epmc_search_(
-        query = query,
-        limit = limit,
-        output = output,
-#        synonym = synonym,
-        verbose = verbose,
-        page_token = page_token,
-        sort = sort
-      )
-    if (page_token == out$next_cursor)
-      break
-    i <- i + 1
-    if (verbose == TRUE)
-      message(paste("Retrieving result page", i))
-    page_token <- out$next_cursor
-    if (output == "raw") {
-      results <- c(results, out$results)
-    } else {
-      results <- dplyr::bind_rows(results, out$results)
-    }
-  }
-  # again, approach needed to use param pageSize instead
-  if (output == "raw") {
-    md <- results[1:limit]
+  if (hits == 0) {
+    message("There are no results matching your query")
+    md <- NULL
   } else {
-    md <- results[1:limit,]
+    limit <- as.integer(limit)
+    limit <- ifelse(hits <= limit, hits, limit)
+    # let's loop over until page max is reached,
+    # or until cursor marks are identical
+    i <- 0
+    # progress
+    pb <- pb(limit = limit)
+    while (i < res_chunks$page_max) {
+      out <-
+        epmc_search_(
+          query = query,
+          limit = limit,
+          output = output,
+          verbose = verbose,
+          page_token = page_token,
+          sort = sort
+        )
+      if (page_token == out$next_cursor)
+        break
+      i <- i + 1
+      if (verbose == TRUE)
+        pb$tick()
+      page_token <- out$next_cursor
+      if (output == "raw") {
+        results <- c(results, out$results)
+      } else {
+        results <- dplyr::bind_rows(results, out$results)
+      }
+    }
+    # again, approach needed to use param pageSize instead
+    if (output == "raw") {
+      md <- results[1:limit]
+    } else {
+      md <- results[1:limit,]
+    }
+    # return hit counts(thanks to @cstubben)
+    attr(md, "hit_count") <- hits
   }
-  # return hit counts(thanks to @cstubben)
-  attr(md, "hit_count") <- hits
   return(md)
 }
 
@@ -139,10 +160,6 @@ epmc_search <- function(query = NULL,
 #'   can become very large.
 #' @param limit integer, limit the number of records you wish to retrieve.
 #'   By default, 25 are returned.
-#' @param sort character, sort results by order (\code{asc}, \code{desc}) and
-#'  sort field (e.g. \code{CITED}, \code{P_PDATE}), seperated with a blank.
-#'  For example, sort results  by times cited in descending order:
-#'  \code{sort = 'CITED desc'}.
 #' @param page_token cursor marking the page
 #'
 #' @param ... further params from \code{\link{epmc_search}}
@@ -154,9 +171,7 @@ epmc_search_ <-
   function(query = NULL,
            limit = 100,
            output = "parsed",
-#           synonym = NULL,
            page_token = NULL,
-           sort = NULL,
            ...) {
     # control limit
     limit <- as.integer(limit)
@@ -174,11 +189,9 @@ epmc_search_ <-
       list(
         query = query,
         format = "json",
-#        synonym = synonym,
         resulttype = resulttype,
         pageSize = page_size,
-        cursorMark = page_token,
-        sort = val_args(sort)
+        cursorMark = page_token
       )
     # call API
     out <-
@@ -200,12 +213,3 @@ epmc_search_ <-
     }
     list(next_cursor = out$nextCursorMark, results = md)
   }
-
-#' encode param for API call
-#' @param x API parameter
-#' @noRd
-val_args <- function(x) {
-  if (!is.null(x))
-    utils::URLencode(x)
-  NULL
-}
