@@ -23,7 +23,8 @@ test_that("epmc_db returns", {
 
   # fails correctly
   expect_error(epmc_db("14756321"), "Please restrict reponse to a database")
-  expect_error(epmc_db("14756321", db = "intact"), "Sorry, no links found")
+  expect_message(epmc_db("14756321", db = "intact"), "Sorry, no links found")
+  expect_null(epmc_db("14756321", db = "intact"))
   expect_error(epmc_db("13814508", data_src = "abc"))
   expect_error(epmc_db("14756321", db = "uniprotl"))
   expect_error(epmc_db("12368864", db = "uniprot", limit = "no"))
