@@ -2,7 +2,7 @@ context("testing epmc_lablinks")
 
 test_that("epmc_lablinks returns", {
   skip_on_cran()
-  a <- epmc_lablinks("25389392", lab_id = "1562")
+  a <- epmc_lablinks("26345659", lab_id = "1056")
   b <- epmc_lablinks("24007304", lab_id = "1507")
   c <- epmc_lablinks("12736239", lab_id = "1056")
 
@@ -16,8 +16,9 @@ test_that("epmc_lablinks returns", {
   expect_is(attr(c, "hit_count"), "integer")
 
   # fails correctly
-  expect_error(epmc_lablinks("13814508", lab_id = "1342"),
+  expect_message(epmc_lablinks("13814508", lab_id = "1342"),
                "Sorry, no links available")
+  expect_null(epmc_lablinks("13814508", lab_id = "1342"))
   expect_error(epmc_lablinks("13814508"))
   expect_error(epmc_lablinks("13814508", n_pages = "abc"))
   expect_error(epmc_lablinks("13814508", data_src = "abc"))
